summaryrefslogtreecommitdiffstats
path: root/kpresenter
diff options
context:
space:
mode:
Diffstat (limited to 'kpresenter')
-rw-r--r--kpresenter/KPrDocument.cpp20
-rw-r--r--kpresenter/KPrDocument.h6
-rw-r--r--kpresenter/KPrFactory.cpp4
-rw-r--r--kpresenter/KPrFactory.h2
-rw-r--r--kpresenter/KPrGotoPage.cpp4
-rw-r--r--kpresenter/KPrTextObject.cpp88
-rw-r--r--kpresenter/KPrTextObject.h8
-rw-r--r--kpresenter/KPrView.cpp10
-rw-r--r--kpresenter/KPrView.h2
-rw-r--r--kpresenter/brushpropertyui.ui2
-rw-r--r--kpresenter/generalpropertyui.ui2
-rw-r--r--kpresenter/gradientpropertyui.ui2
-rw-r--r--kpresenter/imageEffectBase.ui2
-rw-r--r--kpresenter/insertpagedia.ui4
-rw-r--r--kpresenter/marginui.ui2
-rw-r--r--kpresenter/penstyle.ui4
-rw-r--r--kpresenter/picturepropertyui.ui2
-rw-r--r--kpresenter/piepropertyui.ui2
-rw-r--r--kpresenter/polygonpropertyui.ui2
-rw-r--r--kpresenter/rectpropertyui.ui2
-rw-r--r--kpresenter/rotationpropertyui.ui2
-rw-r--r--kpresenter/shadowdialog.ui2
-rw-r--r--kpresenter/slidetransitionwidget.ui2
-rw-r--r--kpresenter/textpropertyui.ui2
24 files changed, 89 insertions, 89 deletions
diff --git a/kpresenter/KPrDocument.h b/kpresenter/KPrDocument.h
index 749b7441..c472c3a3 100644
--- a/kpresenter/KPrDocument.h
+++ b/kpresenter/KPrDocument.h
@@ -128,7 +128,7 @@ class KPrDocument : public KoDocument
public:
// constructor - destructor
- KPrDocument( TQWidget *tqparentWidget = 0, const char *widgetName = 0, TQObject* doc = 0,
+ KPrDocument( TQWidget *parentWidget = 0, const char *widgetName = 0, TQObject* doc = 0,
const char* name = 0, bool singleViewMode = false );
~KPrDocument();
@@ -160,7 +160,7 @@ class KPrDocument : public KoDocument
virtual int supportedSpecialFormats() const;
- virtual bool initDoc(InitDocFlags flags, TQWidget* tqparentWidget=0);
+ virtual bool initDoc(InitDocFlags flags, TQWidget* parentWidget=0);
virtual void setEmpty();
virtual void addView( KoView *_view );
@@ -557,7 +557,7 @@ protected:
virtual bool saveChildren( KoStore* _store );
void loadStyleTemplates( const TQDomElement &styles );
- void saveStyle( KoParagStyle *sty, TQDomElement tqparentElem );
+ void saveStyle( KoParagStyle *sty, TQDomElement parentElem );
TQDomDocumentFragment saveBackground( TQDomDocument& );
TQDomElement saveObjects( TQDomDocument &doc );
diff --git a/kpresenter/KPrFactory.cpp b/kpresenter/KPrFactory.cpp
index 96f71348..076c1ce8 100644
--- a/kpresenter/KPrFactory.cpp
+++ b/kpresenter/KPrFactory.cpp
@@ -43,12 +43,12 @@ KPrFactory::~KPrFactory()
s_global=0;
}
-KParts::Part* KPrFactory::createPartObject( TQWidget *tqparentWidget, const char *widgetName, TQObject* tqparent,
+KParts::Part* KPrFactory::createPartObject( TQWidget *parentWidget, const char *widgetName, TQObject* tqparent,
const char* name, const char* classname, const TQStringList & )
{
bool bWantKoDocument = ( strcmp( classname, "KoDocument" ) == 0 );
- KPrDocument *doc = new KPrDocument( tqparentWidget, widgetName, tqparent, name, !bWantKoDocument );
+ KPrDocument *doc = new KPrDocument( parentWidget, widgetName, tqparent, name, !bWantKoDocument );
if ( !bWantKoDocument )
doc->setReadWrite( false );
diff --git a/kpresenter/KPrFactory.h b/kpresenter/KPrFactory.h
index 6735ac15..be83fc84 100644
--- a/kpresenter/KPrFactory.h
+++ b/kpresenter/KPrFactory.h
@@ -32,7 +32,7 @@ public:
KPrFactory( TQObject* tqparent = 0, const char* name = 0 );
~KPrFactory();
- virtual KParts::Part *createPartObject( TQWidget *tqparentWidget = 0, const char *widgetName = 0, TQObject *tqparent = 0,
+ virtual KParts::Part *createPartObject( TQWidget *parentWidget = 0, const char *widgetName = 0, TQObject *tqparent = 0,
const char *name = 0, const char *classname = "KoDocument",
const TQStringList &args = TQStringList() );
diff --git a/kpresenter/KPrGotoPage.cpp b/kpresenter/KPrGotoPage.cpp
index 6cbb97a7..6a3f8592 100644
--- a/kpresenter/KPrGotoPage.cpp
+++ b/kpresenter/KPrGotoPage.cpp
@@ -86,6 +86,6 @@ int KPrGotoPage::page() const {
}
void KPrGotoPage::resetCursor() {
- if ( tqparentWidget() )
- tqparentWidget()->setCursor( TQt::blankCursor );
+ if ( parentWidget() )
+ parentWidget()->setCursor( TQt::blankCursor );
}
diff --git a/kpresenter/KPrTextObject.cpp b/kpresenter/KPrTextObject.cpp
index 4d1a94c4..c696a8e5 100644
--- a/kpresenter/KPrTextObject.cpp
+++ b/kpresenter/KPrTextObject.cpp
@@ -970,7 +970,7 @@ KoTextFormat KPrTextObject::loadFormat( TQDomElement &n, KoTextFormat * refForma
return format;
}
-KoParagLayout KPrTextObject::loadParagLayout( TQDomElement & tqparentElem, KPrDocument *doc, bool findStyle)
+KoParagLayout KPrTextObject::loadParagLayout( TQDomElement & parentElem, KPrDocument *doc, bool findStyle)
{
KoParagLayout tqlayout;
@@ -980,7 +980,7 @@ KoParagLayout KPrTextObject::loadParagLayout( TQDomElement & tqparentElem, KPrDo
KoParagStyle *style;
// Name of the style. If there is no style, then we do not supply
// any default!
- TQDomElement element = tqparentElem.namedItem( "NAME" ).toElement();
+ TQDomElement element = parentElem.namedItem( "NAME" ).toElement();
if ( !element.isNull() )
{
TQString styleName = element.attribute( "value" );
@@ -1001,7 +1001,7 @@ KoParagLayout KPrTextObject::loadParagLayout( TQDomElement & tqparentElem, KPrDo
tqlayout.style = style;
}
- TQDomElement element = tqparentElem.namedItem( "INDENTS" ).toElement();
+ TQDomElement element = parentElem.namedItem( "INDENTS" ).toElement();
if ( !element.isNull() )
{
double val=0.0;
@@ -1019,7 +1019,7 @@ KoParagLayout KPrTextObject::loadParagLayout( TQDomElement & tqparentElem, KPrDo
val=TQMAX(0, element.attribute("right").toDouble());
tqlayout.margins[TQStyleSheetItem::MarginRight] = val;
}
- element = tqparentElem.namedItem( "LINESPACING" ).toElement();
+ element = parentElem.namedItem( "LINESPACING" ).toElement();
if ( !element.isNull() )
{
//compatibility with koffice 1.1
@@ -1073,7 +1073,7 @@ KoParagLayout KPrTextObject::loadParagLayout( TQDomElement & tqparentElem, KPrDo
}
}
- element = tqparentElem.namedItem( "OFFSETS" ).toElement();
+ element = parentElem.namedItem( "OFFSETS" ).toElement();
if ( !element.isNull() )
{
double val =0.0;
@@ -1087,31 +1087,31 @@ KoParagLayout KPrTextObject::loadParagLayout( TQDomElement & tqparentElem, KPrDo
}
- element = tqparentElem.namedItem( "LEFTBORDER" ).toElement();
+ element = parentElem.namedItem( "LEFTBORDER" ).toElement();
if ( !element.isNull() )
tqlayout.leftBorder = KoBorder::loadBorder( element );
else
tqlayout.leftBorder.setPenWidth( 0);
- element = tqparentElem.namedItem( "RIGHTBORDER" ).toElement();
+ element = parentElem.namedItem( "RIGHTBORDER" ).toElement();
if ( !element.isNull() )
tqlayout.rightBorder = KoBorder::loadBorder( element );
else
tqlayout.rightBorder.setPenWidth( 0);
- element = tqparentElem.namedItem( "TOPBORDER" ).toElement();
+ element = parentElem.namedItem( "TOPBORDER" ).toElement();
if ( !element.isNull() )
tqlayout.topBorder = KoBorder::loadBorder( element );
else
tqlayout.topBorder.setPenWidth(0);
- element = tqparentElem.namedItem( "BOTTOMBORDER" ).toElement();
+ element = parentElem.namedItem( "BOTTOMBORDER" ).toElement();
if ( !element.isNull() )
tqlayout.bottomBorder = KoBorder::loadBorder( element );
else
tqlayout.bottomBorder.setPenWidth(0);
- element = tqparentElem.namedItem( "COUNTER" ).toElement();
+ element = parentElem.namedItem( "COUNTER" ).toElement();
if ( !element.isNull() )
{
tqlayout.counter = new KoParagCounter;
@@ -1119,7 +1119,7 @@ KoParagLayout KPrTextObject::loadParagLayout( TQDomElement & tqparentElem, KPrDo
}
KoTabulatorList tabList;
- element = tqparentElem.firstChild().toElement();
+ element = parentElem.firstChild().toElement();
for ( ; !element.isNull() ; element = element.nextSibling().toElement() )
{
if ( element.tagName() == "TABULATOR" )
@@ -1146,11 +1146,11 @@ KoParagLayout KPrTextObject::loadParagLayout( TQDomElement & tqparentElem, KPrDo
return tqlayout;
}
-void KPrTextObject::saveParagLayout( const KoParagLayout& tqlayout, TQDomElement & tqparentElem )
+void KPrTextObject::saveParagLayout( const KoParagLayout& tqlayout, TQDomElement & parentElem )
{
- TQDomDocument doc = tqparentElem.ownerDocument();
+ TQDomDocument doc = parentElem.ownerDocument();
TQDomElement element = doc.createElement( "NAME" );
- tqparentElem.appendChild( element );
+ parentElem.appendChild( element );
if ( tqlayout.style )
element.setAttribute( "value", tqlayout.style->name() );
else
@@ -1162,7 +1162,7 @@ void KPrTextObject::saveParagLayout( const KoParagLayout& tqlayout, TQDomElement
tqlayout.margins[TQStyleSheetItem::MarginRight] != 0 )
{
element = doc.createElement( "INDENTS" );
- tqparentElem.appendChild( element );
+ parentElem.appendChild( element );
if ( tqlayout.margins[TQStyleSheetItem::MarginFirstLine] != 0 )
element.setAttribute( "first", tqlayout.margins[TQStyleSheetItem::MarginFirstLine] );
if ( tqlayout.margins[TQStyleSheetItem::MarginLeft] != 0 )
@@ -1176,7 +1176,7 @@ void KPrTextObject::saveParagLayout( const KoParagLayout& tqlayout, TQDomElement
tqlayout.margins[TQStyleSheetItem::MarginBottom] != 0 )
{
element = doc.createElement( "OFFSETS" );
- tqparentElem.appendChild( element );
+ parentElem.appendChild( element );
if ( tqlayout.margins[TQStyleSheetItem::MarginTop] != 0 )
element.setAttribute( "before", tqlayout.margins[TQStyleSheetItem::MarginTop] );
if ( tqlayout.margins[TQStyleSheetItem::MarginBottom] != 0 )
@@ -1186,7 +1186,7 @@ void KPrTextObject::saveParagLayout( const KoParagLayout& tqlayout, TQDomElement
if ( tqlayout.lineSpacingType != KoParagLayout::LS_SINGLE )
{
element = doc.createElement( "LINESPACING" );
- tqparentElem.appendChild( element );
+ parentElem.appendChild( element );
if ( tqlayout.lineSpacingType == KoParagLayout::LS_ONEANDHALF )
element.setAttribute( "type", "oneandhalf" );
else if ( tqlayout.lineSpacingType == KoParagLayout::LS_DOUBLE )
@@ -1213,32 +1213,32 @@ void KPrTextObject::saveParagLayout( const KoParagLayout& tqlayout, TQDomElement
if ( tqlayout.leftBorder.penWidth() > 0 )
{
element = doc.createElement( "LEFTBORDER" );
- tqparentElem.appendChild( element );
+ parentElem.appendChild( element );
tqlayout.leftBorder.save( element );
}
if ( tqlayout.rightBorder.penWidth() > 0 )
{
element = doc.createElement( "RIGHTBORDER" );
- tqparentElem.appendChild( element );
+ parentElem.appendChild( element );
tqlayout.rightBorder.save( element );
}
if ( tqlayout.topBorder.penWidth() > 0 )
{
element = doc.createElement( "TOPBORDER" );
- tqparentElem.appendChild( element );
+ parentElem.appendChild( element );
tqlayout.topBorder.save( element );
}
if ( tqlayout.bottomBorder.penWidth() > 0 )
{
element = doc.createElement( "BOTTOMBORDER" );
- tqparentElem.appendChild( element );
+ parentElem.appendChild( element );
tqlayout.bottomBorder.save( element );
}
if ( tqlayout.counter && tqlayout.counter->numbering() != KoParagCounter::NUM_NONE )
{
element = doc.createElement( "COUNTER" );
- tqparentElem.appendChild( element );
+ parentElem.appendChild( element );
if (tqlayout.counter )
tqlayout.counter->save( element );
}
@@ -1248,7 +1248,7 @@ void KPrTextObject::saveParagLayout( const KoParagLayout& tqlayout, TQDomElement
for ( ; it != tabList.end() ; it++ )
{
element = doc.createElement( "TABULATOR" );
- tqparentElem.appendChild( element );
+ parentElem.appendChild( element );
element.setAttribute( "type", (*it).type );
element.setAttribute( "ptpos", (*it).ptPos );
element.setAttribute( "filling", (*it).filling );
@@ -1328,9 +1328,9 @@ void KPrTextObject::drawParags( TQPainter *painter, KoTextZoomHandler* zoomHandl
if ( !parag->isValid() )
parag->format();
if ( i == from )
- r.setTop( m_doc->zoomHandler()->tqlayoutUnitToPixelY( parag->rect().top() ) );
+ r.setTop( m_doc->zoomHandler()->layoutUnitToPixelY( parag->rect().top() ) );
if ( i == to ) {
- r.setBottom( m_doc->zoomHandler()->tqlayoutUnitToPixelY( parag->rect().bottom() ) );
+ r.setBottom( m_doc->zoomHandler()->layoutUnitToPixelY( parag->rect().bottom() ) );
break;
}
++i;
@@ -1361,11 +1361,11 @@ void KPrTextObject::drawCursor( TQPainter *p, KoTextCursor *cursor, bool cursorV
TQPoint topLeft = parag->rect().topLeft(); // in TQRT coords
int lineY;
// Cursor height, in pixels
- int cursorHeight = zh->tqlayoutUnitToPixelY( topLeft.y(), parag->lineHeightOfChar( cursor->index(), 0, &lineY ) );
+ int cursorHeight = zh->layoutUnitToPixelY( topLeft.y(), parag->lineHeightOfChar( cursor->index(), 0, &lineY ) );
TQPoint iPoint( topLeft.x() + cursor->x(),
topLeft.y() + lineY );
// from now on, iPoint will be in pixels
- iPoint = zh->tqlayoutUnitToPixel( iPoint );
+ iPoint = zh->layoutUnitToPixel( iPoint );
TQPoint vPoint = iPoint; // vPoint and iPoint are the same currently
// do not simplify this, will be useful with viewmodes.
@@ -1483,7 +1483,7 @@ void KPrTextObject::highlightPortion( KoTextParag * parag, int index, int length
}
// Now ensure text is fully visible
TQRect rect = m_doc->zoomHandler()->zoomRect( getRect() );
- TQRect expose = m_doc->zoomHandler()->tqlayoutUnitToPixel( parag->rect() );
+ TQRect expose = m_doc->zoomHandler()->layoutUnitToPixel( parag->rect() );
expose.moveBy( rect.x(), rect.y() );
canvas->ensureVisible( (expose.left()+expose.right()) / 2, // point = center of the rect
(expose.top()+expose.bottom()) / 2,
@@ -1578,7 +1578,7 @@ void KPrTextObject::applyStyleChange( KoStyleChangeDefMap changed )
void KPrTextObject::slotAfterFormatting( int bottom, KoTextParag* lastFormatted, bool* abort)
{
recalcVerticalAlignment();
- int availHeight = availableHeight() - m_doc->zoomHandler()->ptToLayoutUnitPixY(tqalignmentValue());
+ int availHeight = availableHeight() - m_doc->zoomHandler()->ptToLayoutUnitPixY(alignmentValue());
if ( ( bottom > availHeight ) || // this parag is already below the avail height
( lastFormatted && (bottom + lastFormatted->rect().height() > availHeight) ) ) // or next parag will be below it
{
@@ -1601,7 +1601,7 @@ void KPrTextObject::slotAfterFormatting( int bottom, KoTextParag* lastFormatted,
// We only auto-grow. We don't auto-shrink.
if(difference > 0 && !isProtect())
{
- double wantedPosition = m_doc->zoomHandler()->tqlayoutUnitPtToPt( m_doc->zoomHandler()->pixelYToPt( difference ) )
+ double wantedPosition = m_doc->zoomHandler()->layoutUnitPtToPt( m_doc->zoomHandler()->pixelYToPt( difference ) )
+ getRect().bottom();
const KoPageLayout& p = m_doc->pageLayout();
double pageBottom = p.ptHeight - p.ptBottom;
@@ -1611,7 +1611,7 @@ void KPrTextObject::slotAfterFormatting( int bottom, KoTextParag* lastFormatted,
if ( getRect().bottom() != newBottom )
{
// We resize the text object, but skipping the KPrTextObject::setSize code
- // (which tqinvalidates everything etc.)
+ // (which invalidates everything etc.)
KPrObject::setSize( getSize().width(), newBottom - getOrig().y() );
// Do recalculate the new available height though
slotAvailableHeightNeeded();
@@ -1652,7 +1652,7 @@ KCommand * KPrTextObject::textContentsToHeight()
}
}
- double textHeight = m_doc->zoomHandler()->tqlayoutUnitPtToPt( textHeightLU );
+ double textHeight = m_doc->zoomHandler()->layoutUnitPtToPt( textHeightLU );
double lineSpacing = ( innerHeight() - textHeight ) / numLines; // this gives the linespacing diff to apply, in pt
//kdDebug(33001) << k_funcinfo << "lineSpacing=" << lineSpacing << endl;
@@ -1681,11 +1681,11 @@ KCommand * KPrTextObject::textObjectToContents()
KoTextParag * parag = textDocument()->firstParag();
double txtWidth = 10;
for ( ; parag ; parag = parag->next() )
- txtWidth = TQMAX( txtWidth, m_doc->zoomHandler()->tqlayoutUnitPtToPt( parag->widthUsed() ));
+ txtWidth = TQMAX( txtWidth, m_doc->zoomHandler()->layoutUnitPtToPt( parag->widthUsed() ));
// Calculate text height
int heightLU = textDocument()->height();
- double txtHeight = m_doc->zoomHandler()->tqlayoutUnitPtToPt( heightLU );
+ double txtHeight = m_doc->zoomHandler()->layoutUnitPtToPt( heightLU );
// Compare with current object's size
KoSize sizeDiff = KoSize( txtWidth, txtHeight ) - innerRect().size();
@@ -1732,7 +1732,7 @@ void KPrTextObject::setVerticalAligment( VerticalAlignmentType _type)
void KPrTextObject::recalcVerticalAlignment()
{
- double txtHeight = m_doc->zoomHandler()->tqlayoutUnitPtToPt( m_doc->zoomHandler()->pixelYToPt( textDocument()->height() ) ) + btop + bbottom;
+ double txtHeight = m_doc->zoomHandler()->layoutUnitPtToPt( m_doc->zoomHandler()->pixelYToPt( textDocument()->height() ) ) + btop + bbottom;
double diffy = getSize().height() - txtHeight;
//kdDebug(33001) << k_funcinfo << "txtHeight: " << txtHeight << " rectHeight:" << getSize().height() << " -> diffy=" << diffy << endl;
@@ -1763,9 +1763,9 @@ TQPoint KPrTextObject::cursorPos(KPrCanvas *canvas, KoTextCursor *cursor) const
TQPoint topLeft = parag->rect().topLeft(); // in TQRT coords
int lineY = 0;
// Cursor height, in pixels
- //int cursorHeight = zh->tqlayoutUnitToPixelY( topLeft.y(), parag->lineHeightOfChar( cursor->index(), 0, &lineY ) );
+ //int cursorHeight = zh->layoutUnitToPixelY( topLeft.y(), parag->lineHeightOfChar( cursor->index(), 0, &lineY ) );
TQPoint iPoint( topLeft.x() + cursor->x(), topLeft.y() + lineY );
- iPoint = zh->tqlayoutUnitToPixel( iPoint );
+ iPoint = zh->layoutUnitToPixel( iPoint );
iPoint.rx() -= canvas->diffx();
iPoint.ry() -= canvas->diffy();
return origPix+iPoint;
@@ -1943,12 +1943,12 @@ void KPrTextView::ensureCursorVisible()
int w = 1;
KPrDocument *doc= m_kptextobj->kPresenterDocument();
KoPoint pt= kpTextObject()->getOrig();
- pt.setX( doc->zoomHandler()->tqlayoutUnitPtToPt( doc->zoomHandler()->pixelXToPt( x) ) +pt.x());
- pt.setY( doc->zoomHandler()->tqlayoutUnitPtToPt( doc->zoomHandler()->pixelYToPt( y ))+pt.y() );
+ pt.setX( doc->zoomHandler()->layoutUnitPtToPt( doc->zoomHandler()->pixelXToPt( x) ) +pt.x());
+ pt.setY( doc->zoomHandler()->layoutUnitPtToPt( doc->zoomHandler()->pixelYToPt( y ))+pt.y() );
TQPoint p = m_kptextobj->kPresenterDocument()->zoomHandler()->zoomPoint( pt );
- w = m_kptextobj->kPresenterDocument()->zoomHandler()->tqlayoutUnitToPixelX( w );
- h = m_kptextobj->kPresenterDocument()->zoomHandler()->tqlayoutUnitToPixelY( h );
+ w = m_kptextobj->kPresenterDocument()->zoomHandler()->layoutUnitToPixelX( w );
+ h = m_kptextobj->kPresenterDocument()->zoomHandler()->layoutUnitToPixelY( h );
m_canvas->ensureVisible( p.x(), p.y() + h / 2, w, h / 2 + 2 );
}
@@ -2515,7 +2515,7 @@ void KPrTextView::dropEvent( TQDropEvent * e )
}
}
-void KPrTextObject::saveParagraph( TQDomDocument& doc,KoTextParag * parag,TQDomElement &tqparentElem,
+void KPrTextObject::saveParagraph( TQDomDocument& doc,KoTextParag * parag,TQDomElement &parentElem,
int from /* default 0 */,
int to /* default length()-2 */ )
{
@@ -2566,7 +2566,7 @@ void KPrTextObject::saveParagraph( TQDomDocument& doc,KoTextParag * parag,TQDomE
else
paragraph.appendChild(saveHelper(tmpText, parag->string()->at(0).format(), doc));
- tqparentElem.appendChild(paragraph);
+ parentElem.appendChild(paragraph);
}
KoPen KPrTextObject::defaultPen() const
@@ -2579,7 +2579,7 @@ TQPoint KPrTextObject::viewToInternal( const TQPoint & pos, KPrCanvas* canvas )
KoTextZoomHandler* zh = kPresenterDocument()->zoomHandler();
TQPoint iPoint = pos - zh->zoomPoint(
getOrig() + KoPoint( bLeft(),
- bTop() + tqalignmentValue()) );
+ bTop() + alignmentValue()) );
iPoint = zh->pixelToLayoutUnit(
TQPoint( iPoint.x() + canvas->diffx(), iPoint.y() + canvas->diffy() ) );
return iPoint;
diff --git a/kpresenter/KPrTextObject.h b/kpresenter/KPrTextObject.h
index 141062d1..41dbe91e 100644
--- a/kpresenter/KPrTextObject.h
+++ b/kpresenter/KPrTextObject.h
@@ -121,10 +121,10 @@ public:
void saveParagraph( TQDomDocument& doc,
KoTextParag * parag,
- TQDomElement &tqparentElem,
+ TQDomElement &parentElem,
int from /* default 0 */,
int to /* default length()-2 */ );
- KoParagLayout loadParagLayout( TQDomElement & tqparentElem, KPrDocument *doc, bool useRefStyle);
+ KoParagLayout loadParagLayout( TQDomElement & parentElem, KPrDocument *doc, bool useRefStyle);
static KoTextFormat loadFormat( TQDomElement &n, KoTextFormat * refFormat, const TQFont & defaultFont,
const TQString & defaultLanguage, bool hyphen );
@@ -169,7 +169,7 @@ public:
VerticalAlignmentType verticalAlignment() const { return m_textVertAlign; }
void setVerticalAligment( VerticalAlignmentType _type) ;
- double tqalignmentValue() const { return alignVertical; }
+ double alignmentValue() const { return alignVertical; }
virtual KPrTextObject *nextTextObject() { return this;}
static void saveFormat( TQDomElement & element, KoTextFormat*lastFormat );
@@ -194,7 +194,7 @@ protected:
virtual void loadKTextObject( const TQDomElement &e );
void drawText( TQPainter* _painter, KoTextZoomHandler* zoomHandler, bool onlyChanged, KoTextCursor* cursor, bool resetChanged );
void drawParags( TQPainter *p, KoTextZoomHandler* zoomHandler, const TQColorGroup& cg, int from, int to );
- void saveParagLayout( const KoParagLayout& tqlayout, TQDomElement & tqparentElem );
+ void saveParagLayout( const KoParagLayout& tqlayout, TQDomElement & parentElem );
void tqinvalidate();
void recalcVerticalAlignment();
virtual KoPen defaultPen() const;
diff --git a/kpresenter/KPrView.h b/kpresenter/KPrView.h
index f50816ba..ecfb736e 100644
--- a/kpresenter/KPrView.h
+++ b/kpresenter/KPrView.h
@@ -781,7 +781,7 @@ protected:
virtual void updateReadWrite( bool readwrite );
void addVariableActions( int type, const TQStringList & texts,
- KActionMenu * tqparentMenu, const TQString & menuText );
+ KActionMenu * parentMenu, const TQString & menuText );
void showParagraphDialog( int initialPage = -1, double initialTabPos = 0.0 );
diff --git a/kpresenter/brushpropertyui.ui b/kpresenter/brushpropertyui.ui
index 58d680cb..4defb83d 100644
--- a/kpresenter/brushpropertyui.ui
+++ b/kpresenter/brushpropertyui.ui
@@ -78,7 +78,7 @@
</widget>
<customwidgets>
</customwidgets>
-<tqlayoutdefaults spacing="6" margin="11"/>
+<layoutdefaults spacing="6" margin="11"/>
<includehints>
<includehint>kcombobox.h</includehint>
<includehint>kcolorbutton.h</includehint>
diff --git a/kpresenter/generalpropertyui.ui b/kpresenter/generalpropertyui.ui
index 4a89074d..eec430f1 100644
--- a/kpresenter/generalpropertyui.ui
+++ b/kpresenter/generalpropertyui.ui
@@ -189,5 +189,5 @@
<data format="PNG" length="1008">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</data>
</image>
</images>
-<tqlayoutdefaults spacing="6" margin="11"/>
+<layoutdefaults spacing="6" margin="11"/>
</UI>
diff --git a/kpresenter/gradientpropertyui.ui b/kpresenter/gradientpropertyui.ui
index 488550d6..bc7f0707 100644
--- a/kpresenter/gradientpropertyui.ui
+++ b/kpresenter/gradientpropertyui.ui
@@ -169,7 +169,7 @@
<tabstop>xSlider</tabstop>
<tabstop>ySlider</tabstop>
</tabstops>
-<tqlayoutdefaults spacing="6" margin="11"/>
+<layoutdefaults spacing="6" margin="11"/>
<includehints>
<includehint>kcolorbutton.h</includehint>
<includehint>kcombobox.h</includehint>
diff --git a/kpresenter/imageEffectBase.ui b/kpresenter/imageEffectBase.ui
index fcdee80c..430bfac8 100644
--- a/kpresenter/imageEffectBase.ui
+++ b/kpresenter/imageEffectBase.ui
@@ -1458,7 +1458,7 @@
<slot>raiseWidget(int)</slot>
</connection>
</connections>
-<tqlayoutdefaults spacing="6" margin="11"/>
+<layoutdefaults spacing="6" margin="11"/>
<includehints>
<includehint>kcolorbutton.h</includehint>
<includehint>knuminput.h</includehint>
diff --git a/kpresenter/insertpagedia.ui b/kpresenter/insertpagedia.ui
index 1984d518..9d7372cf 100644
--- a/kpresenter/insertpagedia.ui
+++ b/kpresenter/insertpagedia.ui
@@ -72,7 +72,7 @@
<property name="title">
<string></string>
</property>
- <property name="tqlayoutMargin" stdset="0">
+ <property name="layoutMargin" stdset="0">
</property>
<vbox>
<property name="name">
@@ -181,5 +181,5 @@
<slot>accept()</slot>
</connection>
</connections>
-<tqlayoutdefaults spacing="6" margin="11"/>
+<layoutdefaults spacing="6" margin="11"/>
</UI>
diff --git a/kpresenter/marginui.ui b/kpresenter/marginui.ui
index ac7ab85e..b4e1bd1e 100644
--- a/kpresenter/marginui.ui
+++ b/kpresenter/marginui.ui
@@ -163,5 +163,5 @@
<tabstops>
<tabstop>synchronize</tabstop>
</tabstops>
-<tqlayoutdefaults spacing="6" margin="11"/>
+<layoutdefaults spacing="6" margin="11"/>
</UI>
diff --git a/kpresenter/penstyle.ui b/kpresenter/penstyle.ui
index a945aff4..bcbcca09 100644
--- a/kpresenter/penstyle.ui
+++ b/kpresenter/penstyle.ui
@@ -186,8 +186,8 @@
<tabstop>lineBeginCombo</tabstop>
<tabstop>lineEndCombo</tabstop>
</tabstops>
-<tqlayoutdefaults spacing="6" margin="11"/>
-<tqlayoutfunctions spacing="KDialog::spacingHint" margin="KDialog::marginHint"/>
+<layoutdefaults spacing="6" margin="11"/>
+<layoutfunctions spacing="KDialog::spacingHint" margin="KDialog::marginHint"/>
<includehints>
<includehint>kcombobox.h</includehint>
<includehint>kcombobox.h</includehint>
diff --git a/kpresenter/picturepropertyui.ui b/kpresenter/picturepropertyui.ui
index 471a9d91..6812256c 100644
--- a/kpresenter/picturepropertyui.ui
+++ b/kpresenter/picturepropertyui.ui
@@ -173,7 +173,7 @@
<tabstop>grayscale</tabstop>
<tabstop>brightnessInput</tabstop>
</tabstops>
-<tqlayoutdefaults spacing="6" margin="11"/>
+<layoutdefaults spacing="6" margin="11"/>
<includehints>
<includehint>knuminput.h</includehint>
</includehints>
diff --git a/kpresenter/piepropertyui.ui b/kpresenter/piepropertyui.ui
index 69300a3a..854e3168 100644
--- a/kpresenter/piepropertyui.ui
+++ b/kpresenter/piepropertyui.ui
@@ -139,7 +139,7 @@
<tabstops>
<tabstop>typeCombo</tabstop>
</tabstops>
-<tqlayoutdefaults spacing="6" margin="11"/>
+<layoutdefaults spacing="6" margin="11"/>
<includehints>
<includehint>kcombobox.h</includehint>
</includehints>
diff --git a/kpresenter/polygonpropertyui.ui b/kpresenter/polygonpropertyui.ui
index e5b7ef56..2b1b87dd 100644
--- a/kpresenter/polygonpropertyui.ui
+++ b/kpresenter/polygonpropertyui.ui
@@ -140,7 +140,7 @@
<data format="PNG" length="826">89504e470d0a1a0a0000000d4948445200000016000000160806000000c4b46c3b0000030149444154388db59531681b5718c77f0e377c070e3c810a3a70e0041eac51852e0a19e45134830a1d9a4c69a04bc8928e990a693a640e1d0c8642b08742321894c1507991b484c890902bb8701a047760c3bd21701fe4201dde49b6a41a32b8df72dcbbeffdbefffbbfefbd5b1b0c07cce266ebe667ae2006c3c1dada0cdc3be87d6e6c35b0d692a409d9c7ec8b20d65ae29398d19b1114e7e3de4ce98b3f5e10dc0053cf0951b4506496e1b964bf7ce6c585d9054c62d01d617ca48be0596553cf496d8f2c8b01c5f795fc93904e85ec4c01a152857a5d9175d0b2805c872080f18595ccc1499a10a225d4e2fbc2877786fe81253ab6c04c8d106e09db5d43ab0d146e5c64d1a23938fb98a185cea1c33eecfd9eba49eb427dcb201e245365f2b7b2fb5b4a3a31dcb927178afe07d86901df870fefa4842aed6f6b74ba42e52b4014d580e1eb9cbd9d94de7e4aad16d2f9be02d805f0b5e532f927a1ffcacea1777f122a8105b164a7c25faf323a5d9f1f1fd600e1e5bec59e2d4b5c7ef5209d0ad17b8b31864e57c0b3e0815ac3ee33253ab664a770ff5185d1a1cb8d2267d3e58aa1dc7d2508cbe597d0e74fdd269aaaf0f52d414c4ea3e9762c996869e42560d7a72e41c4799a2586e74f95e8d8151481fa86efbe7b3398ac58b1a2b8527589f15451ad303ac2293542ad6648a796278f13a27185e4c4754310facb98c53a79e19a3fdc1426ff28c3d7399d1f7cb25343eb96106cf83c790ce9c4f2eb831855c55485663327992eb6dc8a6259874ed700b0b793323cccb9ffa842b30d6133e3e75fea989ac15a8b16ca76b746b0b92278d919774c5b6d48a78697fb29bbcf52468742a32120909c24e899ce67beed5be2db01e22d1e9485bb620e47f9ee9e606a21bd3f5d3744c7e7c54d55e87443867d8b554515ac5db4620e8e4f62263170fd1cdee90aad7640141992891b0f367c9adfe4049bb07d3b7022bd8c687c0978f46684ee084150b65ac1fcca94591b7a90a496e4c095164fb016a2b192a497795cc0f84817aebe25f7bf70ccc54a575c555c03f78ffa5fc0570d1f0c076bff0232285a09643cc7ce0000000049454e44ae426082</data>
</image>
</images>
-<tqlayoutdefaults spacing="6" margin="11"/>
+<layoutdefaults spacing="6" margin="11"/>
<includehints>
<includehint>kcombobox.h</includehint>
<includehint>knuminput.h</includehint>
diff --git a/kpresenter/rectpropertyui.ui b/kpresenter/rectpropertyui.ui
index 4b13a474..ce16ef61 100644
--- a/kpresenter/rectpropertyui.ui
+++ b/kpresenter/rectpropertyui.ui
@@ -177,5 +177,5 @@
<data format="PNG" length="824">89504e470d0a1a0a0000000d4948445200000016000000160806000000c4b46c3b000002ff49444154388db59531681c4714863f992dde820cb370815b50600f54e8ca0ba43970712a8fb838438a3895634813d238a5ab80e314ae4d0a812060a4226017c27221c8a9da6b8c4fe0e00d28b0571cec82043b85611f78c12966efa4bb8bc085f29a6567df7cef9f7fdeccaec571cc2cbaddee47ae21e2385e5b9b815f1ebcfcd8de6a63ad25cb338af7c52741acb5a4a729a3d723a82ec6bd99d267bf3f23fc1c4cab2442d14a915986e792fdfa59569766573049417784f1b12e8267954dab24b78714450a28beaf941f847c2a14e70a0841035a2d45d641eb027213c210c69756320767794684d6508bef0befde1a860796e4c402333542b4256c0f0cdd1e50b97191458be6e0e27d81563a87c643d8fb2d7793d685d696413cc8a6cae46f65f7d79c7c62b87b4f2e15fd0fb0d302be0fefde4a0d557a5f35e90f84e0334014d590f855c9de4ecee17e4eb319d1ff3a00ec02f8c67299f283307c61e7d06fbf1782d082588a33e1cf1705fd81cf773f3601e1f9bec59e2f4b5c7ef5209f0ac95f16630cfd818067c103b586dd274a726229cee0fe8380d191cb4d1267d3d58aa1de7d258ceae5d7d0a78fdd269a86f0c52d414c49bbe3762c9b686de41560d7a72e41c4795a6486a78f95e4c4151481d686efbe7b3398ac58b1a23868b8c474aaa8068c8e714a8dd06c1af2a9e5d1c38c641c909dba6e08237f19b358a7ac5cf3479bc2e41f257e55d2ffc6a73833746f09e186cfa387904f2cbffc90a2aa9886d0e99464d3c5965b512cebd01f1800f67672e2a392fb0f023a3d883a053ffddcc2340dd65ab452b6074dc2cd15c1cbceb863daed413e353cdfcfd97d92333a12da6d0181ec3443cf753ef3cdd092de0e116ff1a02cdc157338ca9d7b8269461cfee1ba2139b9286e1a427f10110f2d561555b076d18a39383d4d99a4c0cd0b787f20747b214962c8266e3cdcf0e97c59126ec2f6edd089f40a92f115e0d1eb11ba238461dd6a15f32b53666de841965bb203575a3cc15a48c64a965fe57105e3635db8fa96dcffc431172b5d715d7103dc3fea7f015f373c8ee3b57f0135105a0fae7717960000000049454e44ae426082</data>
</image>
</images>
-<tqlayoutdefaults spacing="6" margin="11"/>
+<layoutdefaults spacing="6" margin="11"/>
</UI>
diff --git a/kpresenter/rotationpropertyui.ui b/kpresenter/rotationpropertyui.ui
index 08a877cb..ea998478 100644
--- a/kpresenter/rotationpropertyui.ui
+++ b/kpresenter/rotationpropertyui.ui
@@ -158,7 +158,7 @@
</widget>
<customwidgets>
</customwidgets>
-<tqlayoutdefaults spacing="6" margin="11"/>
+<layoutdefaults spacing="6" margin="11"/>
<includehints>
<includehint>knuminput.h</includehint>
<includehint>knuminput.h</includehint>
diff --git a/kpresenter/shadowdialog.ui b/kpresenter/shadowdialog.ui
index 733ebbd5..44fc0e02 100644
--- a/kpresenter/shadowdialog.ui
+++ b/kpresenter/shadowdialog.ui
@@ -492,7 +492,7 @@
<slot access="protected">applyClicked()</slot>
<slot access="protected">okClicked()</slot>
</Q_SLOTS>
-<tqlayoutdefaults spacing="6" margin="11"/>
+<layoutdefaults spacing="6" margin="11"/>
<includehints>
<includehint>kcolorbutton.h</includehint>
</includehints>
diff --git a/kpresenter/slidetransitionwidget.ui b/kpresenter/slidetransitionwidget.ui
index eef5c847..2314d8b9 100644
--- a/kpresenter/slidetransitionwidget.ui
+++ b/kpresenter/slidetransitionwidget.ui
@@ -299,7 +299,7 @@
<tabstop>previewButton</tabstop>
<tabstop>automaticTransitionInput</tabstop>
</tabstops>
-<tqlayoutdefaults spacing="6" margin="11"/>
+<layoutdefaults spacing="6" margin="11"/>
<includehints>
<includehint>klineedit.h</includehint>
<includehint>kpushbutton.h</includehint>
diff --git a/kpresenter/textpropertyui.ui b/kpresenter/textpropertyui.ui
index 2e171cff..0d10315c 100644
--- a/kpresenter/textpropertyui.ui
+++ b/kpresenter/textpropertyui.ui
@@ -54,7 +54,7 @@
<data format="PNG" length="826">89504e470d0a1a0a0000000d4948445200000016000000160806000000c4b46c3b00000301494441541895b59531681b5718c77f0e377c070e3c810a3a70e0041eac51852e0a19e45134830a1d9a4c69a04bc8928e990a693a640e1d0c8642b08742321894c1507991b484c890902bb8701a047760c3bd21701fe4201dde49b6a41a32b8df72dcbbeffdbefffbbfefbd5b1b0c07cce266ebe667ae2006c3c1dada0cdc3be87d6e6c35b0d692a409d9c7ec8b20d65ae29398d19b1114e7e3de4ce98b3f5e10dc0053cf0951b4506496e1b964bf7ce6c585d9054c62d01d617ca48be0596553cf496d8f2c8b01c5f795fc93904e85ec4c01a152857a5d9175d0b2805c872080f18595ccc1499a10a225d4e2fbc2877786fe81253ab6c04c8d106e09db5d43ab0d146e5c64d1a23938fb98a185cea1c33eecfd9eba49eb427dcb201e245365f2b7b2fb5b4a3a31dcb927178afe07d86901df870fefa4842aed6f6b74ba42e52b4014d580e1eb9cbd9d94de7e4aad16d2f9be02d805f0b5e532f927a1ffcacea1777f122a8105b164a7c25faf323a5d9f1f1fd600e1e5bec59e2d4b5c7ef5209d0ad17b8b31864e57c0b3e0815ac3ee33253ab664a770ff5185d1a1cb8d2267d3e58aa1dc7d2508cbe597d0e74fdd269aaaf0f52d414c4ea3e9762c996869e42560d7a72e41c4799a2586e74f95e8d8151481fa86efbe7b3398ac58b1a2b8527589f15451ad303ac2293542ad6648a796278f13a27185e4c4754310facb98c53a79e19a3fdc1426ff28c3d7399d1f7cb25343eb96106cf83c790ce9c4f2eb831855c55485663327992eb6dc8a6259874ed700b0b793323cccb9ffa842b30d6133e3e75fea989ac15a8b16ca76b746b0b92278d919774c5b6d48a78697fb29bbcf52468742a32120909c24e899ce67beed5be2db01e22d1e9485bb620e47f9ee9e606a21bd3f5d3744c7e7c54d55e87443867d8b554515ac5db4620e8e4f62263170fd1cdee90aad7640141992891b0f367c9adfe4049bb07d3b7022bd8c687c0978f46684ee084150b65ac1fcca94591b7a90a496e4c095164fb016a2b192a497795cc0f84817aebe25f7bf70ccc54a575c555c03f78ffa5fc0570d1f0c076bff0232285a09283782c80000000049454e44ae426082</data>
</image>
</images>
-<tqlayoutdefaults spacing="6" margin="11"/>
+<layoutdefaults spacing="6" margin="11"/>
<includehints>
<includehint>kpmarginwidget.h</includehint>
</includehints>
diff --git a/kpresenter/KPrDocument.cpp b/kpresenter/KPrDocument.cpp
index 88f0fd3a..0b33a507 100644
--- a/kpresenter/KPrDocument.cpp
+++ b/kpresenter/KPrDocument.cpp
@@ -136,9 +136,9 @@ KoDocument *KPrChild::hitTest( const TQPoint &, const TQWMatrix & )
return 0;
}
-KPrDocument::KPrDocument( TQWidget *tqparentWidget, const char *widgetName, TQObject* tqparent, const char* name,
+KPrDocument::KPrDocument( TQWidget *parentWidget, const char *widgetName, TQObject* tqparent, const char* name,
bool singleViewMode )
- : KoDocument( tqparentWidget,widgetName, tqparent, name, singleViewMode ),
+ : KoDocument( parentWidget,widgetName, tqparent, name, singleViewMode ),
_gradientCollection(), m_customListTest( 0L ),
m_childCountBeforeInsert( 0 )
{
@@ -3297,7 +3297,7 @@ void KPrDocument::updateHeaderFooterPosition( )
tqrepaint(_footer);
}
-bool KPrDocument::initDoc(InitDocFlags flags, TQWidget* tqparentWidget)
+bool KPrDocument::initDoc(InitDocFlags flags, TQWidget* parentWidget)
{
if (flags==KoDocument::InitDocEmpty)
@@ -3323,7 +3323,7 @@ bool KPrDocument::initDoc(InitDocFlags flags, TQWidget* tqparentWidget)
dlgtype = KoTemplateChooseDia::OnlyTemplates;
ret = KoTemplateChooseDia::choose( KPrFactory::global(), file,
- dlgtype, "kpresenter_template", tqparentWidget );
+ dlgtype, "kpresenter_template", parentWidget );
if ( ret == KoTemplateChooseDia::Template ) {
_clean = true; //was a parameter called "clean", but unused
bool ok = loadNativeFormat( file );
@@ -3605,12 +3605,12 @@ TQString KPrDocument::templateFileName( bool chooseTemplate, const TQString &the
else
fileName = theFile;
} else {
- // TODO: pass tqparentWidget as parameter to this method
- TQWidget* tqparentWidget = 0;
+ // TODO: pass parentWidget as parameter to this method
+ TQWidget* parentWidget = 0;
TQString _template;
if ( KoTemplateChooseDia::choose( KPrFactory::global(), _template,
KoTemplateChooseDia::OnlyTemplates,
- "kpresenter_template", tqparentWidget ) == KoTemplateChooseDia::Cancel )
+ "kpresenter_template", parentWidget ) == KoTemplateChooseDia::Cancel )
return TQString();
TQFileInfo fileInfo( _template );
fileName = fileInfo.dirPath( true ) + "/" + fileInfo.baseName() + ".kpt";
@@ -4410,11 +4410,11 @@ void KPrDocument::applyStyleChange( KoStyleChangeDefMap changed )
m_masterPage->applyStyleChange( changed );
}
-void KPrDocument::saveStyle( KoParagStyle *sty, TQDomElement tqparentElem )
+void KPrDocument::saveStyle( KoParagStyle *sty, TQDomElement parentElem )
{
- TQDomDocument doc = tqparentElem.ownerDocument();
+ TQDomDocument doc = parentElem.ownerDocument();
TQDomElement styleElem = doc.createElement( "STYLE" );
- tqparentElem.appendChild( styleElem );
+ parentElem.appendChild( styleElem );
sty->saveStyle( styleElem );
TQDomElement formatElem = doc.createElement("FORMAT");
diff --git a/kpresenter/KPrView.cpp b/kpresenter/KPrView.cpp
index 7382cc5e..9577bc7d 100644
--- a/kpresenter/KPrView.cpp
+++ b/kpresenter/KPrView.cpp
@@ -4819,15 +4819,15 @@ TQPopupMenu * KPrView::popupMenu( const TQString& name )
}
void KPrView::addVariableActions( int type, const TQStringList & texts,
- KActionMenu * tqparentMenu, const TQString & menuText )
+ KActionMenu * parentMenu, const TQString & menuText )
{
// Single items go directly into tqparentMenu.
// For multiple items we create a submenu.
if ( texts.count() > 1 && !menuText.isEmpty() )
{
KActionMenu * subMenu = new KActionMenu( menuText, actionCollection() );
- tqparentMenu->insert( subMenu );
- tqparentMenu = subMenu;
+ parentMenu->insert( subMenu );
+ parentMenu = subMenu;
}
TQStringList::ConstIterator it = texts.begin();
for ( int i = 0; it != texts.end() ; ++it, ++i )
@@ -4840,7 +4840,7 @@ void KPrView::addVariableActions( int type, const TQStringList & texts,
KAction * act = new KAction( (*it), 0, TQT_TQOBJECT(this), TQT_SLOT( insertVariable() ),
actionCollection(), "var-action" );
m_variableDefMap.insert( act, v );
- tqparentMenu->insert( act );
+ parentMenu->insert( act );
}
}
}
@@ -4819,15 +4819,15 @@ TQPopupMenu * KPrView::popupMenu( const TQString& name )
{
- // Single items go directly into tqparentMenu.
+ // Single items go directly into parentMenu.
// For multiple items we create a submenu.
if ( texts.count() > 1 && !menuText.isEmpty() )